==> openshift-model-operatorhub-5.8.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/CatalogSourceListBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CatalogSourceListBuilder extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceListFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceList,io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceListBuilder>{
  public CatalogSourceListBuilder() {
    this(false);
  }
  public CatalogSourceListBuilder(java.lang.Boolean validationEnabled) {
    this(new CatalogSourceList(), validationEnabled);
  }
  public CatalogSourceListBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceListFluent<?> fluent) {
    this(fluent, false);
  }
  public CatalogSourceListBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CatalogSourceList(), validationEnabled);
  }
  public CatalogSourceListBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceListFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceList instance) {
    this(fluent, instance, false);
  }
  public CatalogSourceListBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceListFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  public CatalogSourceListBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceList instance) {
    this(instance,false);
  }
  public CatalogSourceListBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceList build() {
    CatalogSourceList buildable = new CatalogSourceList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CatalogSourceListBuilder that = (CatalogSourceListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-5.12.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/CatalogSourceListBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CatalogSourceListBuilder extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceListFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceList,io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceListBuilder>{
  public CatalogSourceListBuilder() {
    this(false);
  }
  public CatalogSourceListBuilder(java.lang.Boolean validationEnabled) {
    this(new CatalogSourceList(), validationEnabled);
  }
  public CatalogSourceListBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceListFluent<?> fluent) {
    this(fluent, false);
  }
  public CatalogSourceListBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CatalogSourceList(), validationEnabled);
  }
  public CatalogSourceListBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceListFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceList instance) {
    this(fluent, instance, false);
  }
  public CatalogSourceListBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceListFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CatalogSourceListBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceList instance) {
    this(instance,false);
  }
  public CatalogSourceListBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceList build() {
    CatalogSourceList buildable = new CatalogSourceList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CatalogSourceListBuilder that = (CatalogSourceListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
